[Libreoffice-commits] core.git: sw/qa

Stephan Bergmann sbergman at redhat.com
Wed Jun 4 01:58:38 PDT 2014


 sw/qa/extras/rtfimport/rtfimport.cxx |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit c772e6252aefcd088ea0a5018f303654fc18ac91
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Wed Jun 4 10:57:29 2014 +0200

    testFdo52989 kept failing for my Mac build at least
    
    <vmiklos> sberg: the comment says that it was 2, so unless you're interested in
    debugging it, i would just lower the barrier (423 -> 369)
    
    Change-Id: I0269eab4eee594c4d7aad1c710ed389443208bc4

diff --git a/sw/qa/extras/rtfimport/rtfimport.cxx b/sw/qa/extras/rtfimport/rtfimport.cxx
index 1829490..098a87f 100644
--- a/sw/qa/extras/rtfimport/rtfimport.cxx
+++ b/sw/qa/extras/rtfimport/rtfimport.cxx
@@ -828,8 +828,8 @@ DECLARE_RTFIMPORT_TEST(testFdo52989, "fdo52989.rtf")
 {
     // Same as n#192129, but for JPEG files.
     uno::Reference<drawing::XShape> xShape(getShape(1), uno::UNO_QUERY);
-    // This was 2, should be 423.
-    CPPUNIT_ASSERT(xShape->getSize().Width >= 423);
+    // This was 2, should be 423 (or 369?).
+    CPPUNIT_ASSERT(xShape->getSize().Width >= 369);
 }
 
 DECLARE_RTFIMPORT_TEST(testFdo48442, "fdo48442.rtf")


More information about the Libreoffice-commits mailing list